==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/language/1/barnraiser_01/sch_schedule.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


//SECTION
$lang['section_schedule'] = 						"my schedule";


//HEADER
$lang['hdr_task_allocated'] = 						"allocated tasks";
$lang['hdr_task_initiated'] = 						"initiated tasks";
$lang['hdr_event_attendance'] = 					"event attendance";
$lang['hdr_event_initiated'] = 						"initiated events";


//FORM
$lang['form_label_from_date'] = 					"starting date [mm-dd-yyyy]";
$lang['form_label_show'] = 							"number of days shown";
$lang['form_option_all'] = 							"all";
$lang['form_label_title'] = 						"title";
$lang['form_label_synopsis'] = 						"synopsis";


//ERRORS
$lang['err_no_schedule_items'] = 					"Sorry, there are no schedule items available.";


//LINKS
$lang['href_event_add'] = 							"add event";
$lang['href_task_add'] = 							"add task";



//$lang['hdr_author'] = 								"author";
//$lang['href_event_apply'] = 					"apply to attend this event";
//$lang['href_event_withdraw_confirmation'] = 	"withdraw from this event";
//$lang['href_recommend_this'] = 						"tip this";
//$lang['href_unrecommend_this'] =					"remove tip";
//$lang['href_unwatch_this'] =						"remove mark";
//$lang['href_watch_this'] =							"add mark";
//$lang['section_schedule_item'] = 					"schedule";
//BODY TEXT
//$lang['txt_bc_schedule'] = 							"schedule"; // breadcrumb
//$lang['txt_event_apply'] = 							"apply to attend this event.";
//$lang['txt_event_apply_update'] = 					"reapply for this schedule item";
//$lang['txt_event_full'] = 							"Sorry. this event has all the required participants.";
//$lang['txt_event_withdraw_confirmation'] =			"If you no longer wish to participate you can withdraw. Please remember to inform the schedule organiser why.";
//$lang['txt_allocation'] = 							"allocation";
//$lang['txt_applications'] = 						"applications";
//$lang['txt_confirmed'] = 							"confirmed";
//$lang['txt_end'] = 									"end";
//$lang['txt_location'] = 							"location";
//$lang['txt_start'] = 								"start";
//$lang['txt_type'] = 								"schedule type";
//$lang['txt_profile_create_datetime'] = 				"joined";
//$lang['txt_profile_hometown'] = 					"hometown";
//$lang['txt_profile_nic'] = 							"nickname";
//$lang['txt_profile_session_status'] = 				"status";
//$lang['txt_profile_nic'] = 							"nic";
//$lang['txt_event_allocation_intro'] = 				"You can tell the author of the event that you want to attend my clicking the button. You can withdraw from the event at anytime.";
// Error
//$lang['err_no_schedule_items'] = 				"Sorry, there are no schedule items available.";
//$lang['hdr_tasks'] = 								"tasks";
//$lang['hdr_schedule_creator'] = 					"schedule creator";
//$lang['hdr_schedule_details'] = 					"schedule";
//$lang['hdr_group'] = 								"group";
//$lang['hdr_subject'] = 								"subject";
//$lang['hdr_overview'] = 							"overview";
//$lang['hdr_detail'] = 								"details";
//$lang['hdr_attendance'] = 							"attendance";

?>

==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/language/1/barnraiser_01/sch_schedule.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


//SECTION
$lang['section_schedule'] = 						"my schedule";
$lang['section_group_schedule'] = 					"group schedule";


//HEADER
$lang['hdr_task_allocated'] = 						"allocated tasks";
$lang['hdr_task_initiated'] = 						"initiated tasks";
$lang['hdr_event_attendance'] = 					"event attendance";
$lang['hdr_event_initiated'] = 						"initiated events";
$lang['hdr_events'] = 								"events";
$lang['hdr_tasks'] = 								"tasks";


//FORM
$lang['form_label_from_date'] = 					"starting date [mm-dd-yyyy]";
$lang['form_label_show'] = 							"number of days shown";
$lang['form_option_all'] = 							"all";
$lang['form_label_title'] = 						"title";
$lang['form_label_synopsis'] = 						"synopsis";


//ERRORS
$lang['err_no_schedule_items'] = 					"Sorry, there are no schedule items available.";


//LINKS
$lang['href_event_add'] = 							"add event";
$lang['href_task_add'] = 							"add task";
$lang['href_gantt'] = 								"view gantt chart";


//$lang['hdr_author'] = 								"author";
//$lang['href_event_apply'] = 					"apply to attend this event";
//$lang['href_event_withdraw_confirmation'] = 	"withdraw from this event";
//$lang['href_recommend_this'] = 						"tip this";
//$lang['href_unrecommend_this'] =					"remove tip";
//$lang['href_unwatch_this'] =						"remove mark";
//$lang['href_watch_this'] =							"add mark";
//$lang['section_schedule_item'] = 					"schedule";
//BODY TEXT
//$lang['txt_bc_schedule'] = 							"schedule"; // breadcrumb
//$lang['txt_event_apply'] = 							"apply to attend this event.";
//$lang['txt_event_apply_update'] = 					"reapply for this schedule item";
//$lang['txt_event_full'] = 							"Sorry. this event has all the required participants.";
//$lang['txt_event_withdraw_confirmation'] =			"If you no longer wish to participate you can withdraw. Please remember to inform the schedule organiser why.";
//$lang['txt_allocation'] = 							"allocation";
//$lang['txt_applications'] = 						"applications";
//$lang['txt_confirmed'] = 							"confirmed";
//$lang['txt_end'] = 									"end";
//$lang['txt_location'] = 							"location";
//$lang['txt_start'] = 								"start";
//$lang['txt_type'] = 								"schedule type";
//$lang['txt_profile_create_datetime'] = 				"joined";
//$lang['txt_profile_hometown'] = 					"hometown";
//$lang['txt_profile_nic'] = 							"nickname";
//$lang['txt_profile_session_status'] = 				"status";
//$lang['txt_profile_nic'] = 							"nic";
//$lang['txt_event_allocation_intro'] = 				"You can tell the author of the event that you want to attend my clicking the button. You can withdraw from the event at anytime.";
// Error
//$lang['err_no_schedule_items'] = 				"Sorry, there are no schedule items available.";
//$lang['hdr_tasks'] = 								"tasks";
//$lang['hdr_schedule_creator'] = 					"schedule creator";
//$lang['hdr_schedule_details'] = 					"schedule";
//$lang['hdr_group'] = 								"group";
//$lang['hdr_subject'] = 								"subject";
//$lang['hdr_overview'] = 							"overview";
//$lang['hdr_detail'] = 								"details";
//$lang['hdr_attendance'] = 							"attendance";

?>
